@@ -4,7 +4,7 @@ from paramiko import AutoAddPolicy, SSHClient
 from paramiko.ssh_exception import NoValidConnectionsError
 from scp import SCPClient
 from socket import timeout
-from properties import files
+from .properties import files
 
 def setup(instance):
     from random import choice
